@@ -114,6 +114,8 @@ def convert_timestamp(
         return timestamp_seconds_to_iso(timestamp_seconds)
     elif to_representation == 'TimestampDatetime':
         return timestamp_seconds_to_datetime(timestamp_seconds)
+    elif to_representation == 'TimestampDate':
+        return timestamp_seconds_to_iso(timestamp_seconds)[:10]
     else:
         raise Exception(
             'unknown timestamp representation: ' + str(to_representation)
@@ -185,7 +187,10 @@ def timestamp_to_label(
     )
 
 
-def timestamp_to_iso(timestamp, from_representation=None):
+def timestamp_to_iso(
+    timestamp: spec.Timestamp,
+    from_representation: spec.TimestampRepresentation = None,
+) -> spec.TimestampISO:
     """convert timestamp to TimestampISO
 
     ## Inputs
@@ -320,4 +325,3 @@ def timestamp_to_numerical(
             raise Exception('bad type: ' + str(type(timestamp)))
     else:
         return timestamp_to_seconds_precise(timestamp)
-
